netapp_ontap.resources.audit API documentation
Description: Copyright &copy; 2020 NetApp Inc. All rights reserved …

# Module `netapp_ontap.resources.audit`

Copyright © 2020 NetApp Inc. All rights reserved.

## Overview

Auditing for NAS events is a security measure that enables you to track and log certain CIFS and NFS events on storage virtual machines (SVMs). This helps you track potential security problems and provides evidence of any security breaches.

## Examples

### Creating an audit entry with log rotation size and log retention count

To create an audit entry with log rotation size and log retention count, use the following API. Note the return_records=true query parameter is used to obtain the newly created entry in the response.

    from netapp_ontap import HostConnection
    from netapp_ontap.resources import Audit

    with HostConnection("<mgmt-ip>", username="admin", password="password", verify=False):
        resource = Audit()
        resource.enabled = True
        resource.events.authorization_policy = False
        resource.events.cap_staging = False
        resource.events.cifs_logon_logoff = True
        resource.events.file_operations = True
        resource.events.file_share = False
        resource.events.security_group = False
        resource.events.user_account = False
        resource.log.format = "evtx"
        resource.log.retention.count = 10
        resource.log.rotation.size = 2048000
        resource.log_path = "/"
        resource.svm.name = "vs1"
        resource.svm.uuid = "ec650e97-156e-11e9-abcb-005056bbd0bf"
        resource.post(hydrate=True)
        print(resource)

Try it out

    Audit(
        {
            "log": {
                "rotation": {"size": 2048000},
                "format": "evtx",
                "retention": {"duration": "0s", "count": 10},
            },
            "enabled": True,
            "log_path": "/",
            "svm": {"name": "vs1", "uuid": "ec650e97-156e-11e9-abcb-005056bbd0bf"},
            "events": {
                "file_operations": True,
                "file_share": False,
                "authorization_policy": False,
                "user_account": False,
                "cap_staging": False,
                "security_group": False,
                "cifs_logon_logoff": True,
            },
        }
    )

### Creating an audit entry with log rotation schedule and log retention duration

To create an audit entry with log rotation schedule and log retention duration, use the following API. Note that the return_records=true query parameter is used to obtain the newly created entry in the response.

    from netapp_ontap import HostConnection
    from netapp_ontap.resources import Audit

    with HostConnection("<mgmt-ip>", username="admin", password="password", verify=False):
        resource = Audit()
        resource.enabled = False
        resource.events.authorization_policy = False
        resource.events.cap_staging = False
        resource.events.cifs_logon_logoff = True
        resource.events.file_operations = True
        resource.events.file_share = False
        resource.events.security_group = False
        resource.events.user_account = False
        resource.log.format = "xml"
        resource.log.retention.duration = "P4DT12H30M5S"
        resource.log.rotation.schedule.days = [1, 5, 10, 15]
        resource.log.rotation.schedule.hours = [0, 1, 6, 12, 18, 23]
        resource.log.rotation.schedule.minutes = [10, 15, 30, 45, 59]
        resource.log.rotation.schedule.months = [0]
        resource.log.rotation.schedule.weekdays = [0, 2, 5]
        resource.log_path = "/"
        resource.svm.name = "vs3"
        resource.svm.uuid = "a8d64674-13fc-11e9-87b1-005056a7ae7e"
        resource.post(hydrate=True)
        print(resource)

Try it out

    Audit(
        {
            "log": {
                "rotation": {
                    "schedule": {
                        "hours": [0, 1, 6, 12, 18, 23],
                        "days": [1, 5, 10, 15],
                        "weekdays": [0, 2, 5],
                        "minutes": [10, 15, 30, 45, 59],
                        "months": [0],
                    }
                },
                "format": "xml",
                "retention": {"duration": "P4DT12H30M5S", "count": 0},
            },
            "enabled": True,
            "log_path": "/",
            "svm": {"name": "vs3", "uuid": "a8d64674-13fc-11e9-87b1-005056a7ae7e"},
            "events": {
                "file_operations": True,
                "file_share": False,
                "authorization_policy": False,
                "user_account": False,
                "cap_staging": False,
                "security_group": False,
                "cifs_logon_logoff": True,
            },
        }
    )

### Retrieving an audit configuration for all SVMs in the cluster

    from netapp_ontap import HostConnection
    from netapp_ontap.resources import Audit

    with HostConnection("<mgmt-ip>", username="admin", password="password", verify=False):
        print(list(Audit.get_collection(fields="*", return_timeout=15)))

Try it out

    [
        Audit(
            {
                "log": {
                    "rotation": {"size": 2048000},
                    "format": "evtx",
                    "retention": {"duration": "0s", "count": 10},
                },
                "enabled": True,
                "log_path": "/",
                "svm": {"name": "vs1", "uuid": "ec650e97-156e-11e9-abcb-005056bbd0bf"},
                "events": {
                    "file_operations": True,
                    "file_share": False,
                    "authorization_policy": False,
                    "user_account": False,
                    "cap_staging": False,
                    "security_group": False,
                    "cifs_logon_logoff": True,
                },
            }
        ),
        Audit(
            {
                "log": {
                    "rotation": {
                        "schedule": {
                            "hours": [0, 1, 6, 12, 18, 23],
                            "days": [1, 5, 10, 15],
                            "weekdays": [0, 2, 5],
                            "minutes": [10, 15, 30, 45, 59],
                            "months": [0],
                        }
                    },
                    "format": "xml",
                    "retention": {"duration": "P4DT12H30M5S", "count": 0},
                },
                "enabled": True,
                "log_path": "/",
                "svm": {"name": "vs3", "uuid": "a8d64674-13fc-11e9-87b1-005056a7ae7e"},
                "events": {
                    "file_operations": True,
                    "file_share": False,
                    "authorization_policy": False,
                    "user_account": False,
                    "cap_staging": False,
                    "security_group": False,
                    "cifs_logon_logoff": True,
                },
            }
        ),
    ]

### Retrieving specific entries with event list as cifs-logon-logoff, file-ops = true for an SVM

The configuration returned is identified by the events in the list of audit configurations for an SVM.

    from netapp_ontap import HostConnection
    from netapp_ontap.resources import Audit

    with HostConnection("<mgmt-ip>", username="admin", password="password", verify=False):
        print(
            list(
                Audit.get_collection(
                    return_timeout=15,
                    **{"events.file_operations": "true", "events.cifs_logon_logoff": "true"}
                )
            )
        )

Try it out

    [
        Audit(
            {
                "svm": {"name": "vs1", "uuid": "ec650e97-156e-11e9-abcb-005056bbd0bf"},
                "events": {"file_operations": True, "cifs_logon_logoff": True},
            }
        ),
        Audit(
            {
                "svm": {"name": "vs3", "uuid": "a8d64674-13fc-11e9-87b1-005056a7ae7e"},
                "events": {"file_operations": True, "cifs_logon_logoff": True},
            }
        ),
    ]

### Retrieving a specific audit configuration for an SVM

The configuration returned is identified by the UUID of its SVM.

    from netapp_ontap import HostConnection
    from netapp_ontap.resources import Audit

    with HostConnection("<mgmt-ip>", username="admin", password="password", verify=False):
        resource = Audit(**{"svm.uuid": "ec650e97-156e-11e9-abcb-005056bbd0bf"})
        resource.get()
        print(resource)

Try it out

    Audit(
        {
            "log": {
                "rotation": {"size": 2048000},
                "format": "evtx",
                "retention": {"duration": "0s", "count": 10},
            },
            "enabled": True,
            "log_path": "/",
            "svm": {"name": "vs1", "uuid": "ec650e97-156e-11e9-abcb-005056bbd0bf"},
            "events": {
                "file_operations": True,
                "file_share": False,
                "authorization_policy": False,
                "user_account": False,
                "cap_staging": False,
                "security_group": False,
                "cifs_logon_logoff": True,
            },
        }
    )

### Updating a specific audit configuration of an SVM

The configuration is identified by the UUID of its SVM and the provided information is updated.

    from netapp_ontap import HostConnection
    from netapp_ontap.resources import Audit

    with HostConnection("<mgmt-ip>", username="admin", password="password", verify=False):
        resource = Audit(**{"svm.uuid": "ec650e97-156e-11e9-abcb-005056bbd0bf"})
        resource.enabled = False
        resource.patch()

### Deleting a specific audit configuration for an SVM

The entry to be deleted is identified by the UUID of its SVM.

    from netapp_ontap import HostConnection
    from netapp_ontap.resources import Audit

    with HostConnection("<mgmt-ip>", username="admin", password="password", verify=False):
        resource = Audit(**{"svm.uuid": "ec650e97-156e-11e9-abcb-005056bbd0bf"})
        resource.delete()

## Classes

`class Audit (*args, **kwargs)`

  Auditing for NAS events is a security measure that enables you to track and log certain CIFS and NFS events on SVMs.

  Initialize the instance of the resource.

  Any keyword arguments are set on the instance as properties. For example, if the class was named 'MyResource', then this statement would be true:

      MyResource(name='foo').name == 'foo'

  ## Args

  `*args`
    Each positional argument represents a parent key as used in the URL of the object. That is, each value will be used to fill in a segment of the URL which refers to some parent object. The order of these arguments must match the order they are specified in the URL, from left to right.
  `**kwargs`
    each entry will have its key set as an attribute name on the instance and its value will be the value of that attribute.

  ### Ancestors

  - Resource

  ### Static methods

  `def count_collection(*args, connection: HostConnection = None, **kwargs) -> int`

    Retrieves audit configurations.

    ### Related ONTAP commands

    - `vserver audit show`

    ### Learn more

    - `DOC /protocols/audit`

    Fetch a count of all objects of this type from the host.

    This calls GET on the object to determine the number of records. It is more efficient than calling get_collection() because it will not construct any objects. Query parameters can be passed in as kwargs to determine a count of objects that match some filtered criteria.

    ## Args

    `*args`
      Each entry represents a parent key which is used to build the path to the child object. If the URL definition were /api/foos/{foo.name}/bars, then to get the count of bars for a particular foo, the foo.name value should be passed.
    `connection`
      The `HostConnection` object to use for this API call. If unset, tries to use the connection which is set globally for the library or from the current context.
    `**kwargs`
      Any key/value pairs passed will be sent as query parameters to the host. These query parameters can affect the count. A return_records query param will be ignored.

    ## Returns

    On success, returns an integer count of the objects of this type. On failure, returns -1.

    ## Raises

    `NetAppRestError`: If the API call returned a status code >= 400, or if there is no connection available to use either passed in or on the library.

  `def delete_collection(*args, body: typing.Union = None, connection: HostConnection = None, **kwargs) -> NetAppResponse`

    Deletes an audit configuration.

    ### Related ONTAP commands

    - `vserver audit disable`
    - `vserver audit delete`

    ### Learn more

    - `DOC /protocols/audit`

    Delete all objects in a collection which match the given query.

    All records on the host which match the query will be deleted.

    ## Args

    `*args`
      Each entry represents a parent key which is used to build the path to the child object. If the URL definition were /api/foos/{foo.name}/bars, then to delete the collection of bars for a particular foo, the foo.name value should be passed.
    `body`
      The body of the delete request. This could be a Resource instance or a dictionary object.
    `connection`
      The `HostConnection` object to use for this API call. If unset, tries to use the connection which is set globally for the library or from the current context.
    `**kwargs`
      Any key/value pairs passed will be sent as query parameters to the host. Only resources matching this query will be patched.

    ## Returns

    A `NetAppResponse` object containing the details of the HTTP response.

    ## Raises

    `NetAppRestError`: If the API call returned a status code >= 400

  `def find(*args, connection: HostConnection = None, **kwargs) -> Resource`

    Retrieves audit configurations.

    ### Related ONTAP commands

    - `vserver audit show`

    ### Learn more

    - `DOC /protocols/audit`

    Find an instance of an object on the host given a query.

    The host will be queried with the provided key/value pairs to find a matching resource. If 0 are found, None will be returned. If more than 1 is found, an error will be raised or returned. If there is exactly 1 matching record, then it will be returned.

    ## Args

    `*args`
      Each entry represents a parent key which is used to build the path to the child object. If the URL definition were /api/foos/{foo.name}/bars, then to find a bar for a particular foo, the foo.name value should be passed.
    `connection`
      The `HostConnection` object to use for this API call. If unset, tries to use the connection which is set globally for the library or from the current context.
    `**kwargs`
      Any key/value pairs passed will be sent as query parameters to the host.

    ## Returns

    A `Resource` object containing the details of the object or None if no matches were found.

    ## Raises

    `NetAppRestError`: If the API call returned more than 1 matching resource.

  `def get_collection(*args, connection: HostConnection = None, max_records: int = None, **kwargs) -> typing.Iterable`

    Retrieves audit configurations.

    ### Related ONTAP commands

    - `vserver audit show`

    ### Learn more

    - `DOC /protocols/audit`

    Fetch a list of all objects of this type from the host.

    This is a lazy fetch, making API calls only as necessary when the result of this call is iterated over. For instance, if max_records is set to 5, then iterating over the collection causes an API call to be sent to the server once for every 5 records. If the client stops iterating before getting to the 6th record, then no additional API calls are made.

    ## Args

    `*args`
      Each entry represents a parent key which is used to build the path to the child object. If the URL definition were /api/foos/{foo.name}/bars, then to get the collection of bars for a particular foo, the foo.name value should be passed.
    `connection`
      The `HostConnection` object to use for this API call. If unset, tries to use the connection which is set globally for the library or from the current context.
    `max_records`
      The maximum number of records to return per call
    `**kwargs`
      Any key/value pairs passed will be sent as query parameters to the host.

    ## Returns

    A list of `Resource` objects

    ## Raises

    `NetAppRestError`: If there is no connection available to use either passed in or on the library. This would be not be raised when get_collection() is called, but rather when the result is iterated.

  `def patch_collection(body: dict, *args, connection: HostConnection = None, **kwargs) -> NetAppResponse`

    Updates an audit configuration for an SVM.

    ### Related ONTAP commands

    - `vserver audit modify`

    ### Learn more

    - `DOC /protocols/audit`

    Patch all objects in a collection which match the given query.

    All records on the host which match the query will be patched with the provided body.

    ## Args

    `body`
      A dictionary of name/value pairs to set on all matching members of the collection.
    `*args`
      Each entry represents a parent key which is used to build the path to the child object. If the URL definition were /api/foos/{foo.name}/bars, then to patch the collection of bars for a particular foo, the foo.name value should be passed.
    `connection`
      The `HostConnection` object to use for this API call. If unset, tries to use the connection which is set globally for the library or from the current context.
    `**kwargs`
      Any key/value pairs passed will be sent as query parameters to the host. Only resources matching this query will be patched.

    ## Returns

    A `NetAppResponse` object containing the details of the HTTP response.

    ## Raises

    `NetAppRestError`: If the API call returned a status code >= 400

  ### Methods

  `def delete(self, body: typing.Union = None, poll: bool = True, poll_interval: typing.Union = None, poll_timeout: typing.Union = None, **kwargs) -> NetAppResponse`

    Deletes an audit configuration.

    ### Related ONTAP commands

    - `vserver audit disable`
    - `vserver audit delete`

    ### Learn more

    - `DOC /protocols/audit`

    Send a deletion request to the host for this object.

    ## Args

    `body`
      The body of the delete request. This could be a Resource instance or a dictionary object.
    `poll`
      If set to True, the call will not return until the asynchronous job on the host has completed. Has no effect if the host did not return a job response.
    `poll_interval`
      If the operation returns a job, this specifies how often to query the job for updates.
    `poll_timeout`
      If the operation returns a job, this specifies how long to continue monitoring the job's status for completion.
    `**kwargs`
      Any key/value pairs passed will be sent as query parameters to the host.

    ## Returns

    A `NetAppResponse` object containing the details of the HTTP response.

    ## Raises

    `NetAppRestError`: If the API call returned a status code >= 400

  `def get(self, **kwargs) -> NetAppResponse`

    Retrieves an audit configuration for an SVM.

    ### Related ONTAP commands

    - `vserver audit show`

    ### Learn more

    - `DOC /protocols/audit`

    Fetch the details of the object from the host.

    Requires the keys to be set (if any). After returning, new or changed properties from the host will be set on the instance.

    ## Returns

    A `NetAppResponse` object containing the details of the HTTP response.

    ## Raises

    `NetAppRestError`: If the API call returned a status code >= 400

  `def patch(self, hydrate: bool = False, poll: bool = True, poll_interval: typing.Union = None, poll_timeout: typing.Union = None, **kwargs) -> NetAppResponse`

    Updates an audit configuration for an SVM.

    ### Related ONTAP commands

    - `vserver audit modify`

    ### Learn more

    - `DOC /protocols/audit`

    Send the difference in the object's state to the host as a modification request.

    Calculates the difference in the object's state since the last time we interacted with the host and sends this in the request body.

    ## Args

    `hydrate`
      If set to True, after the response is received from the call, a a GET call will be made to refresh all fields of the object.
    `poll`
      If set to True, the call will not return until the asynchronous job on the host has completed. Has no effect if the host did not return a job response.
    `poll_interval`
      If the operation returns a job, this specifies how often to query the job for updates.
    `poll_timeout`
      If the operation returns a job, this specifies how long to continue monitoring the job's status for completion.
    `**kwargs`
      Any key/value pairs passed will normally be sent as query parameters to the host. If any of these pairs are parameters that are sent as formdata then only parameters of that type will be accepted and all others will be discarded.

    ## Returns

    A `NetAppResponse` object containing the details of the HTTP response.

    ## Raises

    `NetAppRestError`: If the API call returned a status code >= 400

  `def post(self, hydrate: bool = False, poll: bool = True, poll_interval: typing.Union = None, poll_timeout: typing.Union = None, **kwargs) -> NetAppResponse`

    Creates an audit configuration.

    ### Required properties

    - `svm.uuid` or `svm.name` - Existing SVM to which audit configuration is to be created.
    - `log_path` - Path in the owning SVM namespace that is used to store audit logs.

    ### Default property values

    If not specified in POST, the following default property values are assigned: * `enabled` - true * `events.authorization_policy` - false * `events.cap_staging` - false * `events.file_share` - false * `events.security_group` - false * `events.user_account` - false * `events.cifs_logon_logoff` - true * `events.file_operations` - true * `log.format` - evtx * `log.retention.count` - 0 * `log.retention.duration` - PT0S * `log.rotation.size` - 100MB * `log.rotation.now` - false

    ### Related ONTAP commands

    - `vserver audit create`
    - `vserver audit enable`

    ### Learn more

    - `DOC /protocols/audit`

    Send this object to the host as a creation request.

    ## Args

    `hydrate`
      If set to True, after the response is received from the call, a a GET call will be made to refresh all fields of the object.
    `poll`
      If set to True, the call will not return until the asynchronous job on the host has completed. Has no effect if the host did not return a job response.
    `poll_interval`
      If the operation returns a job, this specifies how often to query the job for updates.
    `poll_timeout`
      If the operation returns a job, this specifies how long to continue monitoring the job's status for completion.
    `**kwargs`
      Any key/value pairs passed will normally be sent as query parameters to the host. If any of these pairs are parameters that are sent as formdata then only parameters of that type will be accepted and all others will be discarded.

    ## Returns

    A `NetAppResponse` object containing the details of the HTTP response.

    ## Raises

    `NetAppRestError`: If the API call returned a status code >= 400

  ### Inherited members

  - `Resource`:
    - `from_dict`
    - `get_collection_url`
    - `get_connection`
    - `instance_location`
    - `path_keys`
    - `poll`
    - `set_connection`
    - `to_dict`
`class AuditSchema (*, only: typing.Union = None, exclude: typing.Union = (), many: bool = False, context: typing.Dict = None, load_only: typing.Union = (), dump_only: typing.Union = (), partial: typing.Union = False, unknown: str = None)`

  The fields of the Audit object

  ### Ancestors

  - netapp_ontap.resource.ResourceSchema
  - marshmallow.schema.Schema
  - marshmallow.base.SchemaABC

  ### Class variables

  `enabled GET POST PATCH`

    Specifies whether or not auditing is enabled on the SVM.

  `events GET POST PATCH`

    The events field of the audit.

  `log GET POST PATCH`

    The log field of the audit.

  `log_path GET POST PATCH`

    The audit log destination path where consolidated audit logs are stored.

  `svm GET POST PATCH`

    The svm field of the audit.